.. _reference:

References
==============

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:

   ustat_var.varcovar
   ustat_var.ustat_samp_covar.ustat_samp_covar
   ustat_var.ustat_samp_covar.ustat_samp_covar_fast
   ustat_var.ustat_samp_covar.vcv_samp_covar_XXXX
   ustat_var.ustat_samp_covar.vcv_samp_covar_XXXY
   ustat_var.ustat_samp_covar.vcv_samp_covar_XYXY
   ustat_var.ustat_samp_covar.vcv_samp_covar_XXYY
   ustat_var.sampc
   ustat_var.makec.makec
   ustat_var.makec.makec_spec
   ustat_var.lamb_sum
   ustat_var.lamb_sum.lamb_sum_spec
   ustat_var.generate_test_data.generate_unique_nan_arrays
   ustat_var.generate_test_data.generate_data
   
   
